Embedded Database Formats
=========================

Handlers for embedded database and database-like file formats.

.. autosummary::
   :toctree: generated

   etlplus.file.accdb
   etlplus.file.duckdb
   etlplus.file.mdb
   etlplus.file.sqlite
